<?php
/**
 * Core functions.
 *
 * @package Hait
 */

if ( ! function_exists( 'hait_get_option' ) ) :

    /**
     * Get theme option.
     *
     * @since 1.0.0
     *
     * @param string $key Option key.
     * @return mixed Option value.
     */
    function hait_get_option( $key ) {

        if ( empty( $key ) ) {
            return;
        }

        $hait_default = hait_get_default_theme_options();

        $default = ( isset( $hait_default[ $key ] ) ) ? $hait_default[ $key ] : '';
        $theme_options = get_theme_mod( 'theme_options', $hait_default );
        $theme_options = array_merge( $hait_default, $theme_options );
        $value = '';

        if ( isset( $theme_options[ $key ] ) ) {
            $value = $theme_options[ $key ];
        }

        return $value;

    }

endif;

if ( ! function_exists( 'hait_get_default_theme_options' ) ) :

    /**
     * Get default theme options.
     *
     * @since 1.0.0
     *
     * @return array Default theme options.
     */
    function hait_get_default_theme_options() {

        $defaults = array();

        $defaults['logo_height']            = 50;
        $defaults['hide_site_title']        = false;
        $defaults['hide_tagline']      		= true;

        $defaults['show_search']      		= true;
        $defaults['show_cart']      		= true;
        $defaults['show_profile']      		= true;
        $defaults['profile_link']      		= home_url( '/my-account/' );

        //banner
        $defaults['enable_banner']          = false;
        $defaults['banner_height']      	= 480;
        $defaults['banner_image_left']      = '';
        $defaults['banner_image_right']     = '';
        $defaults['banner_heading']         = esc_html__( 'Minimal WordPress Theme', 'hait' );
        $defaults['banner_button']          = esc_html__( 'Download Now', 'hait' );
        $defaults['banner_link']            = '';

        // Shop page
        $defaults['shop_content_width'] 	= 1200;
        $defaults['product_per_page']       = 9;
        $defaults['product_number']         = 3;
        $defaults['hide_product_breadcrumb']= true;
        $defaults['hide_product_sorting']   = false;

        // Shop single page
        $defaults['shop_content_width_single'] 	= 1200;
        $defaults['enable_gallery_zoom']    	= false;
        $defaults['disable_related_products']	= false;

        //blog
        $defaults['content_width']          = 840;
        $defaults['global_layout']          = 'list-grid';
        $defaults['grid_number']            = 3;
        $defaults['show_date']      		= true;
        $defaults['show_author']      		= true;
        $defaults['show_categories']      	= false;
        $defaults['show_excerpt']      		= true;
        $defaults['excerpt_length']         = 25;
        $defaults['readmore_text']          = esc_html__( 'Continue Reading', 'hait' );

        //blog single
        $defaults['content_width_single']   = 840;
        $defaults['show_date_single']      	= true;
        $defaults['show_author_single']     = true;
        $defaults['show_categories_single'] = true;
        $defaults['show_tags_single'] 		= true;
        $defaults['show_related_posts']     = true;
        $defaults['related_posts_heading']  = esc_html__( 'Related Posts', 'hait' );
        $defaults['related_posts_number']   = 2;
        $defaults['enable_social_share']    = true;

        $defaults['enable_back_to_top']     = true;
        $defaults['footer_style']           = 'normal-background';
        $defaults['copyright_text']         = esc_html__( 'Copyright &copy; 2022 Hait. All rights reserved.', 'hait' );

        return $defaults;
    }

endif;

//=============================================================
// Get all options in array
//=============================================================
if ( ! function_exists( 'hait_get_options' ) ) :

    /**
     * Get all theme options in array.
     *
     * @since 1.0.0
     *
     * @return array Theme options.
     */
    function hait_get_options() {

        $value = array();

        $value = get_theme_mods();

        return $value;

    }

endif;
